SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84

[ROCm/hip-tests commit: 5da168300f]
This commit is contained in:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
committad av GitHub
förälder f35a48c8fb
incheckning eddb025028
14 ändrade filer med 47 tillägg och 47 borttagningar
@@ -43,7 +43,7 @@ void matrixRowSum(int* input, int* output, int width) {
// Device (kernel) function
__global__ void gpuMatrixRowSum(int* input, int* output, int width) {
int index = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int index = blockDim.x * blockIdx.x + threadIdx.x;
#pragma unroll
for (int i = 0; i < width; i++) {
output[index] += input[index * width + i];